@@ -713,3 +713,71 @@ NULL
 #' is the unique words from the combination of \code{\link[qdap]{DICTIONARY}} and
 #' \code{\link[qdap]{labMT}}.
 NULL
+
+#' First Names and Gender (U.S.)
+#' 
+#' A dataset containing 1990 U.S. census data on first names.
+#' 
+#' @details 
+#' \itemize{ 
+#'   \item name. A first name.
+#'   \item per.freq. Frequency in percent of the name by gender.
+#'   \item cum.freq. Cumulative frequency in percent of the name by gender.
+#'   \item rank. Rank of the name by gender.
+#'   \item gender. Gender of the combined male/female list (M/F).
+#'   \item gender2. Gender of the combined male/female list with "B" in place of 
+#'   overlapping (M/F) names.
+#'   \item pred.sex. Predicted gender of the names with B's in \code{gender2} 
+#'   repalced with the gender that had a higher \code{per.freq}.
+#' } 
+#' 
+#' @docType data 
+#' @keywords datasets 
+#' @name NAMES 
+#' @usage data(NAMES) 
+#' @format A data frame with 5494 rows and 7 variables 
+#' @references \url{http://www.census.gov/genealogy/www/data/1990surnames/names_files.html}
+NULL
+ 
+#' First Names and Predictive Gender (U.S.)
+#' 
+#' A truncated version of the \code{link[qdap]{NAMES}}) dataset used for predicting.
+#' 
+#' @details 
+#' \itemize{ 
+#'   \item name. A first name. 
+#'   \item gender2. Gender of the combined male/female list with "B" in place of 
+#'   overlapping (M/F) names.
+#'   \item pred.sex. Predicted gender of the names with B's in \code{gender2} 
+#'   repalced with the gender that had a higher \code{per.freq}.
+#' } 
+#' 
+#' @docType data 
+#' @keywords datasets 
+#' @name NAMES_SEX 
+#' @usage data(NAMES_SEX) 
+#' @format A data frame with 5163 rows and 3 variables 
+#' @references \url{http://www.census.gov/genealogy/www/data/1990surnames/names_files.html}
+NULL
+
+#' First Names and Predictive Gender (U.S.) List
+#' 
+#' A list version of the \code{link[qdap]{NAMES_SEX}}) dataset broken down by 
+#' first letter.
+#' 
+#' @details Alphabetical list of dataframes with the following variables:
+#' \itemize{ 
+#'   \item name. A first name. 
+#'   \item gender2. Gender of the combined male/female list with "B" in place of 
+#'   overlapping (M/F) names.
+#'   \item pred.sex. Predicted gender of the names with B's in \code{gender2} 
+#'   repalced with the gender that had a higher \code{per.freq}.
+#' } 
+#' 
+#' @docType data 
+#' @keywords datasets 
+#' @name NAMES_LIST 
+#' @usage data(NAMES_LIST) 
+#' @format A list with 26 elements 
+#' @references \url{http://www.census.gov/genealogy/www/data/1990surnames/names_files.html}
+NULL
