@@ -69,7 +69,7 @@ function (textString, stopwords = Top25Words, unlist = FALSE, separate = TRUE,
         }
     }
     if (strip) {
-        textString <- qdap::strip(textString, char.keep = char.keep, 
+        textString <- strip(textString, char.keep = char.keep, 
             apostrophe.remove = apostrophe.remove, ...)
     }
     x <- lapply(textString, function(x) SW(x, Stopwords))
